import { __extends, __awaiter, __generator } from 'tslib';
import { Injectable, InjectionToken, Inject, Component, ViewChild, ComponentFactoryResolver, ApplicationRef, Injector, NgModule, Input, Output, EventEmitter, Directive, APP_INITIALIZER } from '@angular/core';
import { I18nBaseService, ShowMessageLinkActionType, ShowMessageType, AbstractShowMessage, MessageDisplayerService, LoadingDefault, DateTimeModule, AuthBaseService, CriticalError, AuthHandlerType, AUTH_SETTINGS, AUTH_TYPE, UserPermissionService, AuthInterceptorHandlerService } from 'totvs-log-base-foundation';
import { Observable } from 'rxjs';
import { map, mergeMap, catchError } from 'rxjs/operators';
import { HttpClient, HTTP_INTERCEPTORS } from '@angular/common/http';
import { ThfI18nService, ThfModalComponent, ThfToasterOrientation, ThfNotificationService, ThfModule, ThfModalModule, ThfComponentsModule, ThfI18nModule } from '@totvs/thf-ui';
import { CommonModule } from '@angular/common';
import { FormsModule, NG_VALIDATORS } from '@angular/forms';
import { Router, NavigationEnd, NavigationStart } from '@angular/router';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço que realiza o carregamento das literais do serviço de internacionalização
 */
var IntlLiteralsLoaderService = /** @class */ (function () {
    /**
     * Método construtor da classe
     * @param http Parâmetro do serviço de Http
     * @param thfI18nService Parâmetro do serviço de internacionalização do THF
     */
    function IntlLiteralsLoaderService(http, thfI18nService) {
        this.http = http;
        this.thfI18nService = thfI18nService;
        /**
         * Atributo com opções de internacionalização Web
         */
        this.webOptions = { context: '', language: '', url: '' };
    }
    /**
     * Método responsável por alterar as opções para carregamento de literais
     * @param options Parâmetro com as opções de internacionalização (url, language, context)
     */
    /**
     * Método responsável por alterar as opções para carregamento de literais
     * @param {?} options Parâmetro com as opções de internacionalização (url, language, context)
     * @return {?}
     */
    IntlLiteralsLoaderService.prototype.updateOptions = /**
     * Método responsável por alterar as opções para carregamento de literais
     * @param {?} options Parâmetro com as opções de internacionalização (url, language, context)
     * @return {?}
     */
    function (options) {
        var _this = this;
        /** @type {?} */
        var obs = new Observable((/**
         * @param {?} observer
         * @return {?}
         */
        function (observer) {
            if (_this.optionsWasChanged(options)) {
                Object.assign(_this.webOptions, options);
                _this.load().subscribe((/**
                 * @param {?} x
                 * @return {?}
                 */
                function (x) {
                    _this.cache = x;
                    observer.next(_this.cache);
                }));
            }
            else if (_this.cache) {
                observer.next(_this.cache);
            }
        }));
        return obs;
    };
    /**
     * Método responsável por realizar o carregamento inicial das literais
     */
    /**
     * Método responsável por realizar o carregamento inicial das literais
     * @return {?}
     */
    IntlLiteralsLoaderService.prototype.load = /**
     * Método responsável por realizar o carregamento inicial das literais
     * @return {?}
     */
    function () {
        var _this = this;
        return this.http.get(this.webOptions.url)
            .pipe(map((/**
         * @param {?} res
         * @return {?}
         */
        function (res) {
            /** @type {?} */
            var s = (/** @type {?} */ (_this.thfI18nService));
            s.config.contexts[_this.webOptions.context] = res;
            s.setVarI18n(s.config.contexts);
            return res;
        })), mergeMap((/**
         * @param {?} res
         * @return {?}
         */
        function (res) { return _this.updateLiteralsFromThfContext(); })), catchError((/**
         * @param {?} e
         * @param {?} caught
         * @return {?}
         */
        function (e, caught) { return caught; })));
    };
    /**
     * Detecta se ocorreram mudanças na configuração
     */
    /**
     * Detecta se ocorreram mudanças na configuração
     * @private
     * @param {?} options
     * @return {?}
     */
    IntlLiteralsLoaderService.prototype.optionsWasChanged = /**
     * Detecta se ocorreram mudanças na configuração
     * @private
     * @param {?} options
     * @return {?}
     */
    function (options) {
        return this.webOptions.context !== options.context
            || this.webOptions.url !== options.url
            || this.webOptions.language !== options.language;
    };
    /**
     * Método responsável por carregar as literais do contexto do THF
     */
    /**
     * Método responsável por carregar as literais do contexto do THF
     * @private
     * @return {?}
     */
    IntlLiteralsLoaderService.prototype.updateLiteralsFromThfContext = /**
     * Método responsável por carregar as literais do contexto do THF
     * @private
     * @return {?}
     */
    function () {
        return this.thfI18nService.getLiterals({
            context: this.webOptions.context,
            language: this.webOptions.language
        }).pipe(map((/**
         * @param {?} res
         * @return {?}
         */
        function (res) { return res; })));
    };
    IntlLiteralsLoaderService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    IntlLiteralsLoaderService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: ThfI18nService }
    ]; };
    return IntlLiteralsLoaderService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Token de configuração da url de internacionalização
 * @type {?}
 */
var INTL_CONFIG = new InjectionToken('Configurações da internacionalização');
/**
 * Serviço de internacionalização
 */
var IntlService = /** @class */ (function (_super) {
    __extends(IntlService, _super);
    /**
     * Método construtor da classe
     * @param config Parâmetro do serviço com as configurações de internacionalização
     * @param intlLiteralsLoader Parâmetro do serviço de carregamento de literais de internacionalização
     */
    function IntlService(config, intlLiteralsLoader) {
        var _this = _super.call(this, intlLiteralsLoader) || this;
        /** @type {?} */
        var matchedAppLanguage;
        if (config.supportedLanguages) {
            matchedAppLanguage = config.supportedLanguages.find((/**
             * @param {?} appSupportedLanguage
             * @return {?}
             */
            function (appSupportedLanguage) {
                return appSupportedLanguage.language === navigator.language;
            }));
            matchedAppLanguage = matchedAppLanguage ? matchedAppLanguage : IntlService.i18nConfig.default.language;
        }
        else {
            matchedAppLanguage = IntlService.i18nConfig.default.language;
            config.supportedLanguages = [{
                    language: IntlService.i18nConfig.default.language
                }];
        }
        _this.updateOptions({
            context: IntlService.i18nConfig.default.context,
            language: matchedAppLanguage.language,
            url: config.url,
            supportedLanguages: config.supportedLanguages
        });
        return _this;
    }
    /**
     * Atributo com as configurações de internacionalização
     */
    IntlService.i18nConfig = {
        contexts: {},
        default: {
            language: 'pt-br',
            context: 'general',
            cache: true
        }
    };
    IntlService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    IntlService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [INTL_CONFIG,] }] },
        { type: IntlLiteralsLoaderService }
    ]; };
    return IntlService;
}(I18nBaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Classe/componente de mensagem
 */
var MessageComponent = /** @class */ (function () {
    function MessageComponent() {
        /**
         * Atributo com o título da mensagem
         */
        this.messageTitle = '';
        /**
         * Atributo com o texto da mensagem
         */
        this.messageText = '';
        /**
         * Atributo com os detalhes da mensagem
         */
        this.messageDetails = '';
        /**
         * Atributo que recebe a ação de confirmação
         */
        this.messageConfirmAction = undefined;
        /**
         * Atributo que recebe a ação de cancelamento
         */
        this.messageCancelAction = undefined;
        /**
         * Atributo que recebe o tipo do link
         */
        this.messageLinkActionType = ShowMessageLinkActionType.No;
        /**
         * Atributo que recebe o link
         */
        this.messageLinkAction = undefined;
        /**
         * Atributo que recebe o label do link
         */
        this.messageLinkLabel = '';
        /**
         * Atributo que indica se os detalhes da mensagem devem ser escondidos
         */
        this.hideDetails = true;
    }
    /**
     * Método responsável por disparar a abertura da dialog
     */
    /**
     * Método responsável por disparar a abertura da dialog
     * @return {?}
     */
    MessageComponent.prototype.openDialog = /**
     * Método responsável por disparar a abertura da dialog
     * @return {?}
     */
    function () {
        this.thfModal.open();
    };
    /**
     * Método responsável por fechar a dialog
     */
    /**
     * Método responsável por fechar a dialog
     * @return {?}
     */
    MessageComponent.prototype.closeDialog = /**
     * Método responsável por fechar a dialog
     * @return {?}
     */
    function () {
        this.thfModal.close();
    };
    /**
     * Método responsável por executar ação do link relacionado a mensagem
     */
    /**
     * Método responsável por executar ação do link relacionado a mensagem
     * @return {?}
     */
    MessageComponent.prototype.linkAction = /**
     * Método responsável por executar ação do link relacionado a mensagem
     * @return {?}
     */
    function () {
        this.messageLinkAction();
    };
    MessageComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-message',
                    template: "<thf-modal\n  [t-title]=\"messageTitle\"\n  [t-primary-action]=\"messageConfirmAction\"\n  [t-secondary-action]=\"messageCancelAction\">\n  <div class=\"message-body\">\n    {{messageText}}\n    <p *ngIf=\"messageLinkActionType\">\n      <a href=\"javascript:void(0)\" (click)=\"linkAction()\">{{messageLinkLabel}}</a>\n    </p>\n    <br/>\n    <div *ngIf=\"messageDetails\" class=\"message-details\">\n      <a *ngIf=\"hideDetails\" class=\"show-details\" href=\"javascript:void(0);\" (click)=\"hideDetails = !hideDetails\">\n        <span class=\"thf-icon thf-icon-arrow-down\"></span>\n        Exibir detalhes\n      </a>\n      <a *ngIf=\"!hideDetails\" class=\"show-details\" href=\"javascript:void(0);\" (click)=\"hideDetails = !hideDetails\">\n        <span class=\"thf-icon thf-icon-arrow-up\"></span>\n        Ocultar detalhes\n      </a>\n      <p [ngClass]=\"{'hide-details': hideDetails}\">\n        {{messageDetails}}\n      </p>\n    </div>    \n  </div>\n</thf-modal>",
                    styles: [".show-details{height:12px;font-family:NunitoSans-Bold;font-size:14px!important;line-height:1.71;text-align:left;color:#1d9abc;padding-top:13px;padding-bottom:15px;text-decoration:none}.hide-details{display:none}.message-body{overflow:hidden;margin-bottom:4px;margin-left:10px;vertical-align:top;min-height:45px}.message-details{margin-top:15px;text-align:center;border-top:1px solid #dbdedf}"]
                }] }
    ];
    MessageComponent.propDecorators = {
        thfModal: [{ type: ViewChild, args: [ThfModalComponent, { static: true },] }]
    };
    return MessageComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço de mensagens
 */
var MessageService = /** @class */ (function (_super) {
    __extends(MessageService, _super);
    /**
     * Método construtor da classe
     * @param thfNotification Parâmetro do serviço de notificação do THF
     * @param componentFactoryResolver Parâmetro do serviço que permite adicionar componentes dinamicamente
     * @param appRef Parâmetro que recebe a referência da aplicação Angular.
     * @param injector Parâmetro do serviço de injeção de dependência
     * @param i18n  Parâmetro do serviço de internacionalização
     */
    function MessageService(thfNotification, componentFactoryResolver, appRef, injector, i18n) {
        var _this = _super.call(this) || this;
        _this.thfNotification = thfNotification;
        _this.componentFactoryResolver = componentFactoryResolver;
        _this.appRef = appRef;
        _this.injector = injector;
        _this.i18n = i18n;
        /**
         * Atributo que recebe a instância da dialog criada
         */
        _this.messageDialogRef = undefined;
        return _this;
    }
    /**
     * Método responsável por exibir uma mensagem, através de notificação ou dialog
     * @param showMessageOptions Parâmetro com as definições da mensagem
     */
    /**
     * Método responsável por exibir uma mensagem, através de notificação ou dialog
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    MessageService.prototype.displayMessage = /**
     * Método responsável por exibir uma mensagem, através de notificação ou dialog
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    function (showMessageOptions) {
        showMessageOptions = showMessageOptions;
        switch (showMessageOptions.messageType) {
            case ShowMessageType.NotificationError:
            case ShowMessageType.NotificationInformation:
            case ShowMessageType.NotificationSuccess:
            case ShowMessageType.NotificationWarning:
                this.showNotification(showMessageOptions);
                break;
            case ShowMessageType.DialogAlert:
            case ShowMessageType.DialogConfirmation:
                this.showDialog(showMessageOptions);
                break;
            default:
                throw new Error("Tipo de mensagem inv\u00E1lido: " + showMessageOptions.messageType);
        }
    };
    /**
     * Método responsável por exibir uma notificação em tela
     * @param showMessageOptions Parâmetro com as definições da mensagem
     */
    /**
     * Método responsável por exibir uma notificação em tela
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    MessageService.prototype.showNotification = /**
     * Método responsável por exibir uma notificação em tela
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    function (showMessageOptions) {
        /** @type {?} */
        var thfNotification = {
            message: showMessageOptions.messageText,
            orientation: ThfToasterOrientation.Top,
            action: this.processLinkAction(showMessageOptions),
            actionLabel: showMessageOptions.messageLinkLabel
        };
        switch (showMessageOptions.messageType) {
            case ShowMessageType.NotificationSuccess:
                this.thfNotification.success(thfNotification);
                break;
            case ShowMessageType.NotificationError:
                this.thfNotification.error(thfNotification);
                break;
            case ShowMessageType.NotificationInformation:
                this.thfNotification.information(thfNotification);
                break;
            case ShowMessageType.NotificationWarning:
                this.thfNotification.warning(thfNotification);
                break;
        }
    };
    /**
     * Método por exibir uma dialog em tela
     * @param showMessageOptions Parâmetro com as definições da mensagem
     */
    /**
     * Método por exibir uma dialog em tela
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    MessageService.prototype.showDialog = /**
     * Método por exibir uma dialog em tela
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    function (showMessageOptions) {
        this.createDialogComponent();
        this.setDialogOptions(showMessageOptions);
        this.messageDialogRef.instance.openDialog();
    };
    /**
     * Método responsável por abrir no navegador uma nova tab com o link recebido por parâmetro
     * @param link Link de uma página externa
     */
    /**
     * Método responsável por abrir no navegador uma nova tab com o link recebido por parâmetro
     * @private
     * @param {?} link Link de uma página externa
     * @return {?}
     */
    MessageService.prototype.openLink = /**
     * Método responsável por abrir no navegador uma nova tab com o link recebido por parâmetro
     * @private
     * @param {?} link Link de uma página externa
     * @return {?}
     */
    function (link) {
        link = link.indexOf('http://') === -1 ? "http://" + link : link;
        window.open(link, '_blank');
    };
    /**
     * Método responsável por identificar se o link recebido é uma função ou página externa
     * @param showMessageOptions Parâmetro com as definições da mensagem
     */
    /**
     * Método responsável por identificar se o link recebido é uma função ou página externa
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    MessageService.prototype.processLinkAction = /**
     * Método responsável por identificar se o link recebido é uma função ou página externa
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    function (showMessageOptions) {
        var _this = this;
        /** @type {?} */
        var action;
        if (showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.Method) {
            action = showMessageOptions.messageLinkAction;
        }
        else if (showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.LinkNewTab &&
            showMessageOptions.messageLinkAction && showMessageOptions.messageLinkAction.trim() !== '') {
            action = (/**
             * @return {?}
             */
            function () {
                _this.openLink(showMessageOptions.messageLinkAction);
            });
        }
        return action;
    };
    /**
     * Método responsável por criar o componente dialog
     */
    /**
     * Método responsável por criar o componente dialog
     * @private
     * @return {?}
     */
    MessageService.prototype.createDialogComponent = /**
     * Método responsável por criar o componente dialog
     * @private
     * @return {?}
     */
    function () {
        if (this.messageDialogRef === undefined) {
            this.messageDialogRef = this.componentFactoryResolver
                .resolveComponentFactory(MessageComponent)
                .create(this.injector);
            this.appRef.attachView(this.messageDialogRef.hostView);
            /** @type {?} */
            var domElem = (/** @type {?} */ (((/** @type {?} */ (this.messageDialogRef.hostView)))
                .rootNodes[0]));
            document.body.appendChild(domElem);
        }
    };
    /**
     * Método responsável por setar as opções do componente dialog
     * @param showMessageOptions Parâmetro com as definições da mensagem
     */
    /**
     * Método responsável por setar as opções do componente dialog
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    MessageService.prototype.setDialogOptions = /**
     * Método responsável por setar as opções do componente dialog
     * @private
     * @param {?} showMessageOptions Parâmetro com as definições da mensagem
     * @return {?}
     */
    function (showMessageOptions) {
        var _this = this;
        if (showMessageOptions.messageTitle !== undefined &&
            showMessageOptions.messageTitle.trim() !== '') {
            this.messageDialogRef.instance.messageTitle = showMessageOptions.messageTitle;
        }
        else if (showMessageOptions.messageType === ShowMessageType.DialogAlert) {
            this.messageDialogRef.instance.messageTitle = this.i18n.literals.warning;
        }
        else if (showMessageOptions.messageType === ShowMessageType.DialogConfirmation) {
            this.messageDialogRef.instance.messageTitle = this.i18n.literals.confirm;
        }
        this.messageDialogRef.instance.messageText = showMessageOptions.messageText;
        this.messageDialogRef.instance.messageDetails = showMessageOptions.messageDetails;
        this.messageDialogRef.instance.messageConfirmAction = {
            action: (/**
             * @return {?}
             */
            function () {
                if (showMessageOptions.messageConfirmAction) {
                    showMessageOptions.messageConfirmAction();
                }
                _this.messageDialogRef.instance.closeDialog();
            }),
            label: showMessageOptions.messageConfirmLabel
        };
        this.messageDialogRef.instance.messageCancelAction = {
            action: (/**
             * @return {?}
             */
            function () {
                if (showMessageOptions.messageCancelAction) {
                    showMessageOptions.messageCancelAction();
                }
                _this.messageDialogRef.instance.closeDialog();
            }),
            label: showMessageOptions.messageCancelLabel
        };
        this.messageDialogRef.instance.messageLinkActionType = showMessageOptions.messageLinkActionType;
        if (showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.LinkNewTab) {
            /** @type {?} */
            var link_1 = showMessageOptions.messageLinkAction;
            showMessageOptions.messageLinkAction = (/**
             * @return {?}
             */
            function () {
                _this.openLink(link_1);
            });
        }
        this.messageDialogRef.instance.messageLinkAction = showMessageOptions.messageLinkAction;
        this.messageDialogRef.instance.messageLinkLabel = showMessageOptions.messageLinkLabel;
    };
    MessageService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    MessageService.ctorParameters = function () { return [
        { type: ThfNotificationService },
        { type: ComponentFactoryResolver },
        { type: ApplicationRef },
        { type: Injector },
        { type: I18nBaseService }
    ]; };
    return MessageService;
}(AbstractShowMessage));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var MessageModule = /** @class */ (function () {
    function MessageModule() {
    }
    MessageModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [MessageComponent],
                    imports: [
                        CommonModule,
                        ThfModule
                    ],
                    exports: [],
                    providers: [
                        MessageService,
                        MessageDisplayerService,
                        {
                            provide: AbstractShowMessage,
                            useClass: MessageService
                        }
                    ]
                },] }
    ];
    return MessageModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ChangeLanguageComponent = /** @class */ (function () {
    function ChangeLanguageComponent(i18n) {
        this.i18n = i18n;
        this.literals = {
            modalTitle: 'changeLanguage',
            radioGroupLabel: 'selectLanguage',
            saveAction: 'save',
            cancelAction: 'cancel'
        };
        this.afterChangeLanguage = new EventEmitter();
        this._languageOptions = [];
    }
    Object.defineProperty(ChangeLanguageComponent.prototype, "primaryAction", {
        get: /**
         * @return {?}
         */
        function () {
            return this._primaryAction;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ChangeLanguageComponent.prototype, "secondaryAction", {
        get: /**
         * @return {?}
         */
        function () {
            return this._secondaryAction;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ChangeLanguageComponent.prototype, "languageOptions", {
        get: /**
         * @return {?}
         */
        function () {
            return this._languageOptions;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    ChangeLanguageComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () { };
    /**
     * @return {?}
     */
    ChangeLanguageComponent.prototype.openChangeLanguageModal = /**
     * @return {?}
     */
    function () {
        this.setModalActions();
        this.setLanguageOptions();
        this.selectedLanguage = this.i18n.getLanguage();
        this.changeLanguageModal.open();
    };
    /**
     * @private
     * @return {?}
     */
    ChangeLanguageComponent.prototype.setModalActions = /**
     * @private
     * @return {?}
     */
    function () {
        var _this = this;
        this._primaryAction = {
            label: this.i18n.literals[this.literals.saveAction],
            action: (/**
             * @return {?}
             */
            function () {
                _this.changeLanguage();
            })
        };
        this._secondaryAction = {
            label: this.i18n.literals[this.literals.cancelAction],
            action: (/**
             * @return {?}
             */
            function () {
                _this.changeLanguageModal.close();
            })
        };
    };
    /**
     * @private
     * @return {?}
     */
    ChangeLanguageComponent.prototype.setLanguageOptions = /**
     * @private
     * @return {?}
     */
    function () {
        var _this = this;
        this._languageOptions = [];
        this.i18n.getSupportedLanguages().forEach((/**
         * @param {?} supportedLanguage
         * @return {?}
         */
        function (supportedLanguage) {
            _this._languageOptions.push({
                label: _this.i18n.literals[supportedLanguage.language],
                value: supportedLanguage.language
            });
        }));
    };
    /**
     * @private
     * @return {?}
     */
    ChangeLanguageComponent.prototype.changeLanguage = /**
     * @private
     * @return {?}
     */
    function () {
        var _this = this;
        /** @type {?} */
        var subscribe = this.i18n.updateOptions({ language: this.selectedLanguage }).subscribe((/**
         * @return {?}
         */
        function () {
            subscribe.unsubscribe();
            _this.afterChangeLanguage.emit(_this.selectedLanguage);
            _this.changeLanguageModal.close();
        }));
    };
    ChangeLanguageComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-change-language',
                    template: "<thf-modal #changeLanguageModal\n  [t-title]=\"i18n.literals[literals.modalTitle]\"\n  t-click-out=\"true\"\n  t-size=\"sm\"\n  [t-primary-action]=\"primaryAction\"\n  [t-secondary-action]=\"secondaryAction\">\n  <thf-radio-group\n    name=\"radioGroupLanguage\"\n    [(ngModel)]=\"selectedLanguage\"\n    [t-label]=\"i18n.literals[literals.radioGroupLabel]\"\n    [t-options]=\"languageOptions\"\n    t-required\n    t-columns=\"1\">\n  </thf-radio-group>\n</thf-modal>",
                    styles: [""]
                }] }
    ];
    /** @nocollapse */
    ChangeLanguageComponent.ctorParameters = function () { return [
        { type: I18nBaseService }
    ]; };
    ChangeLanguageComponent.propDecorators = {
        literals: [{ type: Input }],
        afterChangeLanguage: [{ type: Output }],
        changeLanguageModal: [{ type: ViewChild, args: [ThfModalComponent, { static: true },] }]
    };
    return ChangeLanguageComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var IntlModule = /** @class */ (function () {
    function IntlModule() {
    }
    IntlModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        FormsModule,
                        ThfModalModule,
                        ThfComponentsModule,
                        ThfI18nModule.config(IntlService.i18nConfig)
                    ],
                    exports: [
                        ThfI18nModule,
                        ChangeLanguageComponent
                    ],
                    providers: [
                        IntlService,
                        IntlLiteralsLoaderService,
                        {
                            provide: I18nBaseService,
                            useClass: IntlService
                        }
                    ],
                    declarations: [
                        ChangeLanguageComponent
                    ]
                },] }
    ];
    return IntlModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LoadingComponent = /** @class */ (function () {
    function LoadingComponent() {
        /**
         * Texto do loading
         */
        this.text = '';
        /**
         * Definine se será bloqueada a tela inteira ou apenas o container em que o componente de loading está inserido
         */
        this.screenLock = false;
        /**
         * Define se o loading está sendo mostrado ou não
         */
        this.show = false;
    }
    /**
     * Permite atribuir o texto do loading
     */
    /**
     * Permite atribuir o texto do loading
     * @param {?=} text
     * @return {?}
     */
    LoadingComponent.prototype.setLoadingText = /**
     * Permite atribuir o texto do loading
     * @param {?=} text
     * @return {?}
     */
    function (text) {
        if (text === void 0) { text = ''; }
        this.text = text;
    };
    /**
     * Apresenta o loading, bloqueando a tela
     */
    /**
     * Apresenta o loading, bloqueando a tela
     * @return {?}
     */
    LoadingComponent.prototype.showLoading = /**
     * Apresenta o loading, bloqueando a tela
     * @return {?}
     */
    function () {
        this.show = true;
    };
    /**
     * Esconde o loading, desbloqueando a tela
     */
    /**
     * Esconde o loading, desbloqueando a tela
     * @return {?}
     */
    LoadingComponent.prototype.hideLoading = /**
     * Esconde o loading, desbloqueando a tela
     * @return {?}
     */
    function () {
        this.show = false;
    };
    LoadingComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-loading',
                    template: "<thf-loading-overlay\n    *ngIf=\"show\"\n    [t-screen-lock]=\"screenLock\"\n    [t-text]=\"text\">\n</thf-loading-overlay>",
                    styles: [""]
                }] }
    ];
    return LoadingComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LoadingService = /** @class */ (function (_super) {
    __extends(LoadingService, _super);
    /**
     * Construtor do serviço
     * @param i18n Serviço de internacionalização
     * @param componentFactoryResolver Serviço que permite adicionar componentes dinamicamente
     * @param appRef Referência da aplicação Angular
     * @param injector Serviço de injeção de dependência
     */
    function LoadingService(i18n, componentFactoryResolver, appRef, injector) {
        var _this = _super.call(this) || this;
        _this.i18n = i18n;
        _this.componentFactoryResolver = componentFactoryResolver;
        _this.appRef = appRef;
        _this.injector = injector;
        /**
         * Referência para o componente de loading no html
         */
        _this.loadingComponentRef = undefined;
        /**
         * Texto apresentado durante o loading
         */
        _this.loadingText = '';
        return _this;
    }
    /**
     * Exibe o loading, bloqueando a tela
     */
    /**
     * Exibe o loading, bloqueando a tela
     * @return {?}
     */
    LoadingService.prototype.showLoading = /**
     * Exibe o loading, bloqueando a tela
     * @return {?}
     */
    function () {
        if (this.loadingComponentRef === undefined) {
            this.createLoadingComponent();
        }
        this.loadingComponentRef.instance.showLoading();
    };
    /**
     * Esconde o loading, desbloqueando a tela
     */
    /**
     * Esconde o loading, desbloqueando a tela
     * @return {?}
     */
    LoadingService.prototype.hideLoading = /**
     * Esconde o loading, desbloqueando a tela
     * @return {?}
     */
    function () {
        if (this.loadingComponentRef !== undefined) {
            this.loadingComponentRef.instance.hideLoading();
        }
    };
    /**
     * Atribui o texto que será apresentado
     * @param text Texto a ser apresentado, devendo ser um BaseMessage
     */
    /**
     * Atribui o texto que será apresentado
     * @param {?} text Texto a ser apresentado, devendo ser um BaseMessage
     * @return {?}
     */
    LoadingService.prototype.setLoadingText = /**
     * Atribui o texto que será apresentado
     * @param {?} text Texto a ser apresentado, devendo ser um BaseMessage
     * @return {?}
     */
    function (text) {
        this.loadingText = this.i18n.text(text) ? this.i18n.text(text).text : '';
        if (this.loadingComponentRef === undefined) {
            this.createLoadingComponent();
        }
        this.loadingComponentRef.instance.text = this.loadingText;
    };
    /**
     * Método privado que cria dinamicamente o componente de loading no DOM
     */
    /**
     * Método privado que cria dinamicamente o componente de loading no DOM
     * @private
     * @return {?}
     */
    LoadingService.prototype.createLoadingComponent = /**
     * Método privado que cria dinamicamente o componente de loading no DOM
     * @private
     * @return {?}
     */
    function () {
        if (this.loadingComponentRef === undefined) {
            this.loadingComponentRef = this.componentFactoryResolver
                .resolveComponentFactory(LoadingComponent)
                .create(this.injector);
            this.appRef.attachView(this.loadingComponentRef.hostView);
            /** @type {?} */
            var domElem = (/** @type {?} */ (((/** @type {?} */ (this.loadingComponentRef.hostView)))
                .rootNodes[0]));
            document.body.appendChild(domElem);
        }
    };
    LoadingService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    LoadingService.ctorParameters = function () { return [
        { type: I18nBaseService },
        { type: ComponentFactoryResolver },
        { type: ApplicationRef },
        { type: Injector }
    ]; };
    return LoadingService;
}(LoadingDefault));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serviço responsável por métodos e atributos utilizados por toda aplicação web
 */
var GlobalService = /** @class */ (function () {
    /**
     * Método construtor que inicializa a classe
     * @param i18n Parâmetro do serviço de internacionalização
     * @param msg  Parâmetro do serviço de mensagens
     * @param loading Parâmetro do serviço de loading
     */
    function GlobalService(i18n, msg, loading) {
        this.i18n = i18n;
        this.msg = msg;
        this.loading = loading;
    }
    GlobalService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    GlobalService.ctorParameters = function () { return [
        { type: I18nBaseService },
        { type: MessageDisplayerService },
        { type: LoadingService }
    ]; };
    return GlobalService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LoadingModule = /** @class */ (function () {
    function LoadingModule() {
    }
    LoadingModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [LoadingComponent],
                    imports: [
                        CommonModule,
                        ThfModule
                    ],
                    exports: [],
                    providers: [
                        LoadingService
                    ]
                },] }
    ];
    return LoadingModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var i18nFactory = (/**
 * @param {?} i18n
 * @param {?} config
 * @return {?}
 */
function (i18n, config) {
    return (/**
     * @return {?}
     */
    function () { return new Promise((/**
     * @param {?} resolve
     * @return {?}
     */
    function (resolve) {
        if (config.lazy) {
            resolve(true);
        }
        else {
            i18n.updateOptions({}).subscribe((/**
             * @return {?}
             */
            function () {
                resolve(true);
            }), (/**
             * @param {?} error
             * @return {?}
             */
            function (error) {
                console.error(error);
                resolve(false);
            }));
        }
    })); });
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @return {?}
 */
function cpfValidator() {
    return (/**
     * @param {?} control
     * @return {?}
     */
    function (control) {
        if (Validator.cpfIsInvalid(control.value)) {
            return { cpfInvalido: control.value };
        }
        else {
            return null;
        }
    });
}
/**
 * @return {?}
 */
function cnpjValidator() {
    return (/**
     * @param {?} control
     * @return {?}
     */
    function (control) {
        if (Validator.cnpjIsInvalid(control.value)) {
            return { cnpjInvalido: control.value };
        }
        else {
            return null;
        }
    });
}
var Validator = /** @class */ (function () {
    function Validator() {
    }
    /**
     * @param {?} cpf
     * @return {?}
     */
    Validator.cpfIsInvalid = /**
     * @param {?} cpf
     * @return {?}
     */
    function (cpf) {
        return !Validator.cpfIsValid(cpf);
    };
    /**
     * @param {?} stringCPF
     * @return {?}
     */
    Validator.cpfIsValid = /**
     * @param {?} stringCPF
     * @return {?}
     */
    function (stringCPF) {
        if (stringCPF === null || stringCPF === '') {
            return false;
        }
        if (stringCPF === '00000000000' ||
            stringCPF === '11111111111' ||
            stringCPF === '22222222222' ||
            stringCPF === '33333333333' ||
            stringCPF === '44444444444' ||
            stringCPF === '55555555555' ||
            stringCPF === '66666666666' ||
            stringCPF === '77777777777' ||
            stringCPF === '88888888888' ||
            stringCPF === '99999999999') {
            return false;
        }
        /** @type {?} */
        var sum = 0;
        for (var i = 1; i <= 9; i++) {
            sum += parseInt(stringCPF.substring(i - 1, i), 10) * (11 - i);
        }
        /** @type {?} */
        var remaining = (sum * 10) % 11;
        if (remaining === 10 || remaining === 11) {
            remaining = 0;
        }
        if (remaining !== parseInt(stringCPF.substring(9, 10), 10)) {
            return false;
        }
        sum = 0;
        for (var i = 1; i <= 10; i++) {
            sum += parseInt(stringCPF.substring(i - 1, i), 10) * (12 - i);
        }
        remaining = (sum * 10) % 11;
        if (remaining === 10 || remaining === 11) {
            remaining = 0;
        }
        if (remaining !== parseInt(stringCPF.substring(10, 11), 10)) {
            return false;
        }
        return true;
    };
    /**
     * @param {?} cnpj
     * @return {?}
     */
    Validator.cnpjIsInvalid = /**
     * @param {?} cnpj
     * @return {?}
     */
    function (cnpj) {
        return !Validator.cnpjIsValid(cnpj);
    };
    /**
     * @param {?} cnpj
     * @return {?}
     */
    Validator.cnpjIsValid = /**
     * @param {?} cnpj
     * @return {?}
     */
    function (cnpj) {
        if (cnpj === '' || cnpj === null) {
            return false;
        }
        if (cnpj.length !== 14) {
            return false;
        }
        if (cnpj === '00000000000000' ||
            cnpj === '11111111111111' ||
            cnpj === '22222222222222' ||
            cnpj === '33333333333333' ||
            cnpj === '44444444444444' ||
            cnpj === '55555555555555' ||
            cnpj === '66666666666666' ||
            cnpj === '77777777777777' ||
            cnpj === '88888888888888' ||
            cnpj === '99999999999999') {
            return false;
        }
        /** @type {?} */
        var size = cnpj.length - 2;
        /** @type {?} */
        var numbers = cnpj.substring(0, size);
        /** @type {?} */
        var digits = cnpj.substring(size);
        /** @type {?} */
        var sum = 0;
        /** @type {?} */
        var pos = size - 7;
        for (var i = size; i >= 1; i--) {
            sum += numbers.charAt(size - i) * pos--;
            if (pos < 2) {
                pos = 9;
            }
        }
        /** @type {?} */
        var primeiroDigitoVerificador = Number(digits.charAt(0));
        /** @type {?} */
        var segundoDigitoVerificador = Number(digits.charAt(1));
        /** @type {?} */
        var result = sum % 11 < 2 ? 0 : 11 - sum % 11;
        if (result !== primeiroDigitoVerificador) {
            return false;
        }
        size = size + 1;
        numbers = cnpj.substring(0, size);
        sum = 0;
        pos = size - 7;
        for (var i = size; i >= 1; i--) {
            sum += numbers.charAt(size - i) * pos--;
            if (pos < 2) {
                pos = 9;
            }
        }
        result = sum % 11 < 2 ? 0 : 11 - sum % 11;
        if (result !== segundoDigitoVerificador) {
            return false;
        }
        return true;
    };
    /**
     * @param {?} cnpj
     * @return {?}
     */
    Validator.cnpjFormatter = /**
     * @param {?} cnpj
     * @return {?}
     */
    function (cnpj) {
        /** @type {?} */
        var cnpjFormated = cnpj.split('');
        cnpjFormated.splice(2, 0, '.');
        cnpjFormated.splice(6, 0, '.');
        cnpjFormated.splice(10, 0, '/');
        cnpjFormated.splice(15, 0, '-');
        /** @type {?} */
        var cnpjFormatedFinal = cnpjFormated.toString().replace(/[,]/g, '');
        return cnpjFormatedFinal;
    };
    /**
     * @param {?} cpf
     * @return {?}
     */
    Validator.cpfFormatter = /**
     * @param {?} cpf
     * @return {?}
     */
    function (cpf) {
        /** @type {?} */
        var cpfFormated = cpf.split('');
        cpfFormated.splice(3, 0, '.');
        cpfFormated.splice(7, 0, '.');
        cpfFormated.splice(11, 0, '-');
        /** @type {?} */
        var cpfFormatedFinal = cpfFormated.toString().replace(/[,]/g, '');
        return cpfFormatedFinal;
    };
    Validator.CPF_SIZE = 11;
    Validator.PLACA_SIZE = 7;
    Validator.CNPJ_SIZE = 14;
    Validator.MAX_FILE_SIZE_5_MB = 5000000;
    return Validator;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var CpfValidateDirective = /** @class */ (function () {
    function CpfValidateDirective() {
    }
    /**
     * @param {?} control
     * @return {?}
     */
    CpfValidateDirective.prototype.validate = /**
     * @param {?} control
     * @return {?}
     */
    function (control) {
        return cpfValidator()(control);
    };
    CpfValidateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[cpfValidate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: cpfValidator, multi: true }]
                },] }
    ];
    return CpfValidateDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var CnpjValidateDirective = /** @class */ (function () {
    function CnpjValidateDirective() {
    }
    /**
     * @param {?} control
     * @return {?}
     */
    CnpjValidateDirective.prototype.validate = /**
     * @param {?} control
     * @return {?}
     */
    function (control) {
        return cnpjValidator()(control);
    };
    CnpjValidateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[cnpjValidate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: cnpjValidator, multi: true }]
                },] }
    ];
    return CnpjValidateDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Módulo que exporta e ativas as dependências basicas do foundation
 * Para garantir que os serviços tenham uma única instância, usar FndModule.forRoot() ao importar
 */
var FndModule = /** @class */ (function () {
    function FndModule() {
    }
    /**
     * @return {?}
     */
    FndModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: FndModule,
            providers: [
                GlobalService,
                {
                    provide: APP_INITIALIZER,
                    useFactory: i18nFactory,
                    deps: [I18nBaseService, INTL_CONFIG],
                    multi: true
                }
            ]
        };
    };
    FndModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        ThfModule,
                        IntlModule,
                        MessageModule,
                        DateTimeModule,
                        LoadingModule
                    ],
                    declarations: [
                        CpfValidateDirective,
                        CnpjValidateDirective
                    ],
                    exports: [
                        IntlModule,
                        MessageModule,
                        DateTimeModule,
                        LoadingModule,
                        CnpjValidateDirective,
                        CpfValidateDirective
                    ],
                    entryComponents: [MessageComponent, LoadingComponent]
                },] }
    ];
    return FndModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Representa um componente para aceitar o redirecionamento de callback do fluxo de oauth2
 */
var AuthCallbackComponent = /** @class */ (function () {
    /**
     * Creates an instance of AuthCallbackComponent.
     */
    function AuthCallbackComponent(router, authService) {
        var _this = this;
        this.router = router;
        this.authService = authService;
        this.router.events.forEach((/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            if (event instanceof NavigationEnd) {
                _this.authService
                    .completeAuthentication()
                    .then((/**
                 * @return {?}
                 */
                function () {
                    _this.authService
                        .getUser()
                        .then((/**
                     * @param {?} user
                     * @return {?}
                     */
                    function (user) {
                        _this.authService.userLoadedEvent.emit(user);
                    }));
                }));
            }
        }));
    }
    /**
     * @return {?}
     */
    AuthCallbackComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    AuthCallbackComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-auth-callback',
                    template: ''
                }] }
    ];
    /** @nocollapse */
    AuthCallbackComponent.ctorParameters = function () { return [
        { type: Router },
        { type: AuthBaseService }
    ]; };
    return AuthCallbackComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Implementação de guard com uso do serviço de autenticação padrão
 */
var AuthGuard = /** @class */ (function () {
    /**
     * Creates an instance of AuthGuard.
     */
    function AuthGuard(authService) {
        this.authService = authService;
    }
    /**
     * Implementação do serviço angular que previne o carregamento de componentes, se necessário
     */
    /**
     * Implementação do serviço angular que previne o carregamento de componentes, se necessário
     * @return {?}
     */
    AuthGuard.prototype.canActivate = /**
     * Implementação do serviço angular que previne o carregamento de componentes, se necessário
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var isAuthorized, user;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.authService.authorize()];
                    case 1:
                        isAuthorized = _a.sent();
                        if (!isAuthorized) return [3 /*break*/, 3];
                        return [4 /*yield*/, this.authService.getUser()];
                    case 2:
                        user = _a.sent();
                        this.authService.userLoadedEvent.next(user);
                        _a.label = 3;
                    case 3: return [2 /*return*/, isAuthorized];
                }
            });
        });
    };
    AuthGuard.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    AuthGuard.ctorParameters = function () { return [
        { type: AuthBaseService }
    ]; };
    return AuthGuard;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AuthService = /** @class */ (function (_super) {
    __extends(AuthService, _super);
    /**
     * Método construtor da classe
     * @param authSettings Token de injeção com as configurações de autenticação
     * @param authType Token de injeção com o tipo de autenticação
     */
    function AuthService(authSettings, authType) {
        var _this = _super.call(this, AuthService.AddOriginUrls(authSettings)) || this;
        _this.authSettings = authSettings;
        _this.authType = authType;
        if (_this.authSettings === undefined) {
            throw new CriticalError('authSettings: undefined');
        }
        if (_this.authType === undefined) {
            throw new CriticalError('authType: undefined');
        }
        return _this;
    }
    /**
     * Adiciona nas uris de redirecionamento do processo oauth o host de origem, se um host não for informado
     * Isso é para permitir que o navegador identifique o domínio de redirecionamento
     * utilizando o caminho relativo
     *
     * @param authSettings as configurações de autenticação
     * @returns as configurações de autenticação com uris normalizadas para o processo de autenticação
     */
    /**
     * Adiciona nas uris de redirecionamento do processo oauth o host de origem, se um host não for informado
     * Isso é para permitir que o navegador identifique o domínio de redirecionamento
     * utilizando o caminho relativo
     *
     * @param {?} authSettings as configurações de autenticação
     * @return {?} as configurações de autenticação com uris normalizadas para o processo de autenticação
     */
    AuthService.AddOriginUrls = /**
     * Adiciona nas uris de redirecionamento do processo oauth o host de origem, se um host não for informado
     * Isso é para permitir que o navegador identifique o domínio de redirecionamento
     * utilizando o caminho relativo
     *
     * @param {?} authSettings as configurações de autenticação
     * @return {?} as configurações de autenticação com uris normalizadas para o processo de autenticação
     */
    function (authSettings) {
        if (authSettings) {
            authSettings.redirect_uri = AuthService.AddOriginUrl(window.location.origin, authSettings.redirect_uri);
            authSettings.post_logout_redirect_uri
                = AuthService.AddOriginUrl(window.location.origin, authSettings.post_logout_redirect_uri);
            authSettings.silent_redirect_uri = AuthService.AddOriginUrl(window.location.origin, authSettings.silent_redirect_uri);
            if (!authSettings.post_logout_redirect_uri) {
                authSettings.post_logout_redirect_uri = window.location.origin;
            }
        }
        return authSettings;
    };
    /**
     * Adiciona o host na url, se nenhum host estiver presente
     * @param host o host a ser adicionado
     * @param url url em que o host será adicionado
     * @returns a junção da url e host
     */
    /**
     * Adiciona o host na url, se nenhum host estiver presente
     * @param {?} host o host a ser adicionado
     * @param {?} url url em que o host será adicionado
     * @return {?} a junção da url e host
     */
    AuthService.AddOriginUrl = /**
     * Adiciona o host na url, se nenhum host estiver presente
     * @param {?} host o host a ser adicionado
     * @param {?} url url em que o host será adicionado
     * @return {?} a junção da url e host
     */
    function (host, url) {
        if (url.trim().length !== 0 && !url.startsWith(host) && !url.startsWith('http')) {
            url = "" + host + url;
        }
        return url;
    };
    /**
     * Verifica se está em atuação o fluxo de login e deveria ou não mostrar o menu
     */
    /**
     * Verifica se está em atuação o fluxo de login e deveria ou não mostrar o menu
     * @param {?} router
     * @return {?}
     */
    AuthService.prototype.shouldShowMenu = /**
     * Verifica se está em atuação o fluxo de login e deveria ou não mostrar o menu
     * @param {?} router
     * @return {?}
     */
    function (router) {
        /** @type {?} */
        var loginFlow = false;
        router.events.forEach((/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            if (event instanceof NavigationStart) {
                loginFlow = event.url === '' || event.url === '/' || event.url.startsWith('/auth-callback');
                // vai redirecionar, guarda a rota atual
                if (!loginFlow) {
                    localStorage.setItem('current.route', event.url);
                }
            }
        }));
        return loginFlow;
    };
    /**
     * Monta um ThfToolbarProfile a partir do usuário. Sem suporte a avatar no momento
     */
    /**
     * Monta um ThfToolbarProfile a partir do usuário. Sem suporte a avatar no momento
     * @param {?} user
     * @return {?}
     */
    AuthService.prototype.getToolbarProfile = /**
     * Monta um ThfToolbarProfile a partir do usuário. Sem suporte a avatar no momento
     * @param {?} user
     * @return {?}
     */
    function (user) {
        return {
            title: user && user.profile ? user.profile.name : null,
            subtitle: user && user.profile ? user.profile.email : null
        };
    };
    /**
     * Método responsável executar o processo de login/autenticação
     */
    /**
     * Método responsável executar o processo de login/autenticação
     * @return {?}
     */
    AuthService.prototype.loginFlow = /**
     * Método responsável executar o processo de login/autenticação
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!(this.authType.type === AuthHandlerType.oauth2)) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.signinRedirect()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Método responsável executar o processo de logout
     */
    /**
     * Método responsável executar o processo de logout
     * @return {?}
     */
    AuthService.prototype.logoutFlow = /**
     * Método responsável executar o processo de logout
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!(this.authType.type === AuthHandlerType.oauth2)) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.signoutRedirect()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    AuthService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    AuthService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [AUTH_SETTINGS,] }] },
        { type: undefined, decorators: [{ type: Inject, args: [AUTH_TYPE,] }] }
    ]; };
    return AuthService;
}(AuthBaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Módulo que exporta e ativas as dependências para utilizar autenticação com fluxo oauth2
 * Para garantir que os serviços tenham uma única instância, usar AuthModule.forRoot() ao importar
 */
var AuthModule = /** @class */ (function () {
    function AuthModule() {
    }
    /**
     * @return {?}
     */
    AuthModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: AuthModule,
            providers: [
                AuthService,
                UserPermissionService,
                {
                    provide: AuthBaseService,
                    useClass: AuthService
                },
                AuthGuard
            ]
        };
    };
    AuthModule.decorators = [
        { type: NgModule, args: [{
                    imports: [],
                    exports: [],
                    entryComponents: [],
                    providers: [
                        {
                            provide: HTTP_INTERCEPTORS,
                            useClass: AuthInterceptorHandlerService,
                            multi: true
                        }
                    ],
                    declarations: [AuthCallbackComponent]
                },] }
    ];
    return AuthModule;
}());

export { AuthCallbackComponent, AuthGuard, AuthModule, AuthService, ChangeLanguageComponent, CnpjValidateDirective, CpfValidateDirective, FndModule, GlobalService, INTL_CONFIG, IntlLiteralsLoaderService, IntlModule, IntlService, LoadingComponent, LoadingModule, LoadingService, MessageComponent, MessageModule, MessageService, Validator, cnpjValidator, cpfValidator, i18nFactory };
//# sourceMappingURL=totvs-log-web-foundation.js.map
